import React, {useState} from 'react';
import './App.css';
import Todo from "./Todo";
import {TodoItem} from "./types";

function App() {
    const [todos, setTodos] = useState<TodoItem[]>([]);
    const [text, setText] = useState("");

    const handleAddTodo = () => {
        if (text.trim() === "") return;
        const newTodo: TodoItem = {
            id: todos.length + 1,
            text: text,
            completed: false,
        };

        setTodos([...todos, newTodo]);
        setText("");
    }

    const handleToggleTodo = (id: number) => {
        const updatedTodos = todos.map((todo) => {
            if (todo.id === id) {
                return {...todo, completed: !todo.completed};
            }
            return todo;
        });

        setTodos(updatedTodos);
    }

    const handleDeleteTodo = (id: number) => {
        const updatedTodos = todos.filter((todo) => todo.id !== id);
        setTodos(updatedTodos);
    }

    return (
        <div>
            <h1>Todo List</h1>
            <input
                type="text"
                value={text}
                onChange={(e) => setText(e.target.value)}
            />
            <button onClick={handleAddTodo}>Add Todo</button>
            <ul>
                {todos.map((todo) => (
                    <Todo
                        key={todo.id}
                        id={todo.id}
                        text={todo.text}
                        completed={todo.completed}
                        onToggle={handleToggleTodo}
                        onDelete={handleDeleteTodo}
                    />
                ))}
            </ul>
        </div>
    );
}

export default App;
